module.exports = defineTest({
	description: 'Resolve template literals in computed property keys'
});
